import QtQuick 1.0
import QtMobility.location 1.1
import QtMobility.systeminfo 1.1
import Places 1.0
import "util.js" as Util
import com.nokia.meego 1.0
import com.nokia.extras 1.0

Rectangle {

    width: 480
    height: 820
    anchors.fill: parent
    color: "#000000"
    id: root

    property bool updateRunning: false

    Timer {
        id: weatherTimer
        interval: 300000
        repeat: true
        triggeredOnStart : false
        onTriggered: {
            if (!(factory.background)) {
                console.log("Refreshing forecasts");
                refreshingForecasts();
                factory.parseLocationsFromNetwork(factory.networkUpdate);
            }
        }
    }

    Timer {
        id: weatherRefreshedTimer
        interval: 10070
        repeat: true
        triggeredOnStart : false
        onTriggered: {
            if (Util.refreshedTimeInMs !== undefined && !updateRunning) {
                var currentTimeInMs = new Date().getTime();
                var diff = Math.floor(currentTimeInMs - Util.refreshedTimeInMs) / 1000;
                var DAY_LENGTH = 3600*24;
                if (diff < 0) {
                    refreshed.text = qsTr("updated") + " " + qsTr("just now");
                } else if (diff < 3600 && diff/60 >= 1.0) {
                    refreshed.text = qsTr("updated") + " " + qsTr("%n minute(s) ","",Math.floor(diff/60)) + qsTr("ago");
                } else if (diff < DAY_LENGTH && diff/3600 >= 1.0) {
                    refreshed.text = qsTr("updated") + " " + qsTr("%n hour(s) ","",Math.floor(diff/3600)) + qsTr("ago");
                } else if (diff > DAY_LENGTH) {
                    refreshed.text = qsTr("updated") + " " + qsTr("%n day(s) ","",Math.floor(diff/DAY_LENGTH)) + qsTr("ago");
                }
            }
        }
    }

    Timer {
        id: screenRotateTimer
        interval: 200
        repeat: true
        triggeredOnStart : false
        onTriggered: {
            if (((root.width > parent.height) && (!factory.landscape)) ||
                ((root.width < parent.height) && (factory.landscape)))
            {
                factory.landscape = (root.width > root.height);
            };
            if (factory.laterThan5min() && !(factory.background)) {
                console.log("Refreshing forecasts");
                refreshingForecasts();
                //if (city.text === "&^%$#") city.text ="@#$%^"; else city.text = "&^%$#";
                factory.parseLocationsFromNetwork(factory.networkUpdate);
            };
            waitCursor.visible = (root.width > root.height) && (factory.locations[factory.currentLocation].forecastsCount === 0);
        }
    }

    GeneralInfo {
        id: ginfo
        onCurrentLanguageChanged: {

        }
    }

    DeviceInfo {
        id: dinfo
    }

    function manualRefreshForecasts() {
        weatherTimer.stop();
        weatherRefreshedTimer.stop();
        console.log("Refreshing forecasts");
        refreshingForecasts();
        factory.parseLocationsFromNetwork(factory.networkUpdate);
        weatherTimer.start();
        weatherRefreshedTimer.start();
    }

    function refreshingForecasts() {
        if (!(factory.background)) {
            updateRunning = true;
            if ((city.text === "") || factory.isUpdatingNow) {
                if (city.text === "") {
                    city.text = qsTr("find_currect_location");
                };
                if (factory.isUpdatingNow) {
                    weather_big.anchors.leftMargin = (5*weather_big.width)/9;
                    weather_big.source = "qrc:/res/earth.png";
                    date_description.text = "";
                    date_description_part2.text = "";
                    temperature.text = "";
                    temperature_part2.text = "";
                    humidity.text = "";
                    humidity_part2.text = "";
                    pressure.text = "";
                    pressure_part2.text = "";
                    wind.text = "";
                    wind_part2.text = "";
                    windicon.visible = false;
                    weather_desc.text = "";
                };
                factory.isUpdatingNow = false;
                weather_big.anchors.leftMargin = (5*weather_big.width)/9;
            }
            refreshed.text = qsTr("refreshing_in_progress");
        } else updateRunning = false;
    }

    function showNewForecast() {
        weather_big.anchors.leftMargin = (Util.marginDefault)/2;
        if (factory.locations[factory.currentLocation].forecastsCount === 0) {
            weather_big.anchors.leftMargin = (5*weather_big.width)/9;
        };
        updateRunning = false;
        if (factory.locationsCount === 0) {
            city.text = qsTr("undefined_location");
        } else {
            city.text = factory.locations[factory.currentLocation].prefName;
        }
        var forecast = factory.locations[factory.currentLocation].forecasts[Util.currentForecastIndx];
        if (forecast === undefined)
            return;
        weather_big.source = "image://weather/" + forecast.iconDescription;
        var s;
        temperature.anchors.topMargin = (forecast.forecastType === Forecast.Daily) ? ((3*parent.height)/64) + 4 : Util.marginDefault;
        temperature.font.pixelSize = (forecast.forecastType === Forecast.Daily) ? Util.dailyTfontSize : Util.mainTfontSize;
        temperature_part2.anchors.topMargin = (forecast.forecastType === Forecast.Daily) ? ((3*parent.height)/64) + 4 : Util.marginDefault;
        temperature_part2.font.pixelSize = (forecast.forecastType === Forecast.Daily) ? Util.dailyTfontSize : Util.mainTfontSize;
        if (factory.t === GismeteoFactory.Centigrade) {
            s = forecast.temperatureDescription(false) + "°C_";
        } else {
            s = forecast.temperatureDescription(true) + "°F_";
        }
        temperature.text = s.substr(0, s.indexOf("°"));
        temperature_part2.text = s.substr(s.indexOf("°"), s.indexOf("_") - s.indexOf("°"));
        s = forecast.minHumidity + "% " + qsTr("humidity") + "_";
        humidity.text = s.substr(0, s.indexOf(" ") + 1);
        humidity_part2.text = s.substr(s.indexOf(" ") + 1, s.indexOf("_") - s.indexOf(" ") - 1);
        if (factory.p === GismeteoFactory.MmHgSt) {
            s = forecast.pressure + " " + qsTr("mmHg");
        } else {
            s = Math.round((forecast.pressure*1000)/760) + " " + qsTr("gPa");
        }
        s = s + "_";
        pressure.text = s.substr(0, s.indexOf(" ") + 1);
        pressure_part2.text = s.substr(s.indexOf(" ") + 1, s.indexOf("_") - s.indexOf(" ") - 1);

        var WindDir1 = [qsTr('Calm'), qsTr('N'), qsTr('NE'), qsTr('E'), qsTr('SE'), qsTr('S'), qsTr('SW'), qsTr('W'), qsTr('NW')];
        s = "";
        var wndspd = forecast.windSpeed;
        var wnddir = forecast.windDirection;
        //if (locale !== "ru" && locale !== "ua") {
        //    wndspd = Math.round((wndspd * 3600000) / 1609344);
        //}
        if (wndspd === 0)
            wnddir = Forecast.Calm;
        if (wndspd === 0 || wnddir === Forecast.Calm) {
            s = WindDir1[wnddir];
        } else {
            if (factory.ws === GismeteoFactory.Mps) {
                s = wndspd + ' ' + qsTr("mps") + ', ' + WindDir1[wnddir];
            } else {
                s = Math.round((wndspd*36)/10) + ' ' + qsTr("kmh") + ', ' + WindDir1[wnddir];
            }
        }
        s = s + "_";
        if (wndspd === 0 || wnddir === Forecast.Calm) {
            wind.text = WindDir1[Forecast.Calm];
            wind_part2.text = "";
        } else {
            wind.text = s.substr(0, s.indexOf(" ") + 1);
            wind_part2.text = s.substr(s.indexOf(" ") + 1, s.indexOf("_") - s.indexOf(" ") - 1);
        };
        s = forecast.dateDescription(false) + "_";
        date_description.text = s.substr(0, s.indexOf(",") + 1);
        date_description_part2.text = s.substr(s.indexOf(",") + 1, s.indexOf("_") - s.indexOf(",") - 1);
        if (wnddir !== Forecast.Calm && wndspd !== 0) {
            windicon.rotation = (forecast.windDirection - 1)*45;
            windicon.visible = true;
        } else {
            windicon.visible = false;
        }
        weather_desc.text = forecast.description;
        while (weather_desc.height > Util.descriptionRowHeight*2) {
            var indx = weather_desc.text.lastIndexOf(",");
            if (indx !== -1) {
                weather_desc.text = weather_desc.text.substring(0,indx);
            }
        }
        weather_desc.height = Util.descriptionRowHeight*2;
    }

    function updateForecastList() {
        var indx = -1, curIndex;
        if (factory.screenRotated) {
            curIndex = fcList.currentIndex;
        };
        fcList.model.clear();
        for (var i=0; i<factory.locations[factory.currentLocation].forecastsCount; i++) {
            var fc = factory.locations[factory.currentLocation].forecasts[i];
            if (fc.forecastType === Forecast.Fact) {
                console.log("!!!Fact!!!");
            }

            var fShow = (factory.fDaily && (fc.forecastType === Forecast.Daily)) ||
                ((!factory.fDaily) && (fc.forecastType === Forecast.Hourly || fc.forecastType === Forecast.Fact));
            if (fShow && (fc.forecastType === Forecast.Fact)) {
                console.log("!!!Fact (1)!!!");
            }
            if (fShow) {
                if (indx == -1)
                    indx = i;
                fcList.model.append({"forecast": fc, "forecastIndex": i, "isLastItem": false});
            }
        };
        //fcList.model.append({"forecast": "", "forecastIndex": 0, "isLastItem": true});

        fcList.visible = true;
        fcList.currentIndex = 0;
        if (factory.screenRotated) {
            factory.screenRotated = false;
            fcList.currentIndex = curIndex;
        };

        Util.currentForecastIndx = indx;
    }

    InfoBanner {
         id: infobanner
         text: ""
    }

    //GismeteoFactory {
    //    id: factory
    Item {
        id: factoryContainer

        Component.onCompleted: {
            ginfo.startCurrentLanguageChanged();
            if (Util.descriptionRowHeight === 0) {
                weather_desc.text = "1\n1";
                Util.descriptionRowHeight = weather_desc.height/2;
                weather_desc.text = " \n ";
                weather_desc.height = Util.descriptionRowHeight*2;
            }
            refreshingForecasts();
            factory.landscape = (parent.width > parent.height);
            console.log("find hash...");
            var isError = false;
            var imei = dinfo.imei;
            var hash = factory.getHashFromDB();
            //var hash = Util.getHashFromDb(imei);
            console.log(hash);
            if ((hash === "") || (hash === "undefined")) {
                console.log("Hash not found " + dinfo.imei)
                var doc = new XMLHttpRequest();
                doc.onreadystatechange = function() {
                    if (doc.readyState == XMLHttpRequest.DONE) {
                        if (doc.status != 200 && doc.status !== 0 || doc.responseXML === undefined) {
                            console.log("Network error " + doc.status + " " + doc.statusMessage);
                        }
                        console.log(doc.status);
                        var a = doc.responseXML.documentElement;
                        var error = Util.parseError(a.childNodes[1]);
                        if (error.code === 0) {
                            hash = a.childNodes[3].childNodes[1].childNodes[0].nodeValue;
                            console.log("Hash obtained from network " + hash);
                            if (hash !== undefined) {
                                factory.insertHash(hash);
                                console.log("Hash inserted " + hash);
                                factory.userhash = hash;
                            }
                        } else {
                            isError = true;
                            console.log("Error " + error.code + " " + error.message);
                        }
                    }
                }
                doc.open("GET", "http://0c23a8bf.services.gismeteo.ru/inform-service/register/?id=" + encodeURIComponent(imei) + "&nocache=1");
                doc.send();
            } else {
                console.log("Hash found " + hash);
                factory.userhash = hash;
            };
            if (!isError) {
                factory.updateLocationsProc(false);
                factory.readSettingsFromDB();
                screenRotateTimer.start();
            }
        }

        Connections {
            target: factory

            onUpdateForecastsSignal: {
                console.log("update forecasts signal " + cityid);
                Util.updateForecastsForLoc(cityid);
            }
            onUpdateLocationsSignal: {
                console.log("update locations signal");
                factory.updateLocationsFromDB();
                if (factory.locationsCount === 0) {
                    factory.findMode = false;
                    factory.getPosition();
                }
                else {
                    factory.readSettingsFromDB();
                    factory.parseLocationsFromNetwork(factory.networkUpdate);
                }
            }
            onForecastsUpdated: {
                if (!(factory.background)) {
                    weatherTimer.start();
                    console.log("current location");
                    console.log(factory.currentLocation);
                    if (fNetwork) {
                        console.log("...network...");
                    } else {
                        console.log("...database...");
                    }
                    weatherRefreshedTimer.start();
                    Util.refreshedTimeInMs = new Date().getTime();
                    updateForecastList();
                    showNewForecast();
                    factory.setSuccessUpdateFlag();
                    screenRotateTimer.start();
                    if (fNetwork) {
                        console.log("...network");
                        Util.refreshedTimeInMs = new Date().getTime();
                        refreshed.text = qsTr("updated") + " " + qsTr("just now");
                    } else {
                        var currentTimeInMs = new Date().getTime();
                        Util.refreshedTimeInMs = factory.updateTimeFromDB.getTime();
                        var diff = Math.floor(currentTimeInMs - factory.updateTimeFromDB.getTime()) / 1000;
                        refreshed.text = qsTr("updated") + " " + qsTr("just now");
                        var DAY_LENGTH = 3600*24;
                        if (diff < 0) {
                            refreshed.text = qsTr("updated") + " " + qsTr("just now");
                        } else if (diff < 3600 && diff/60 >= 1.0) {
                            refreshed.text = qsTr("updated") + " " + qsTr("%n minute(s) ","",Math.floor(diff/60)) + qsTr("ago");
                        } else if (diff < DAY_LENGTH && diff/3600 >= 1.0) {
                            refreshed.text = qsTr("updated") + " " + qsTr("%n hour(s) ","",Math.floor(diff/3600)) + qsTr("ago");
                        } else if (diff > DAY_LENGTH) {
                            refreshed.text = qsTr("updated") + " " + qsTr("%n day(s) ","",Math.floor(diff/DAY_LENGTH)) + qsTr("ago");
                        }
                    };
                }
            }
            onOptionsUpdated: {
                updateForecastList();
                showNewForecast();
            }
            onLocNameUpdated: {
                city.text = factory.locations[factory.currentLocation].prefName;
            }
            onUpdateList: {
                updateForecastList();
                showNewForecast();
            }
            onUpdateListIndex: {
                Util.currentForecastIndx = index;
                showNewForecast();
            }
            onLanguageChangedSignal: {
                if (factory.locations[factory.currentLocation].prefName === "") {
                    city.text = qsTr("refreshing_in_progress");
                } else {
                    city.text = factory.locations[factory.currentLocation].prefName;
                }
                factory.parseCitiesFromNetwork();
                manualRefreshForecasts();
                if (updateRunning) {
                    if (factory.locations[factory.currentLocation].prefName === "") {
                        city.text = qsTr("refreshing_in_progress");
                    } else {
                        city.text = factory.locations[factory.currentLocation].prefName;
                    }
                }
                //toolbutton2.text = qsTr("Refresh");
            }
            onUpdateLocationsSignalForLocPage: {
                if (factory.laterThan5min() && !(factory.background)) {
                    console.log("Refreshing forecasts");
                    refreshingForecasts();
                    factory.parseLocationsFromNetwork(factory.networkUpdate);
                }
            }
            onConnectionError: {
                //console.log("ERROR!!! " + errorMessage + ' ' + errorCode);
                //infobanner.text = "network_error";
                if (isNetworkError) {
                    infobanner.text = qsTr("network_error");
                } else {
                    infobanner.text = errorCode + ' ' + errorMessage;
                };
                infobanner.timerShowTime = 5000;
                infobanner.show();
                refreshed.text = qsTr("no_network");
                if (factory.locationsCount === 0) {
                    city.text = qsTr("undefined_location");
                } else {
                    if (factory.locations[factory.currentLocation].forecastsCount === 0) {
                        refreshed.text = qsTr("no_network");
                    };
                };
                updateRunning = false;
            }
        }
    }

    Rectangle {

        id: header;
        anchors.left: parent.left;
        anchors.right: parent.right;
        anchors.top: parent.top //st.bottom;
        height: commonToolBar.height
        radius: 0
/*        gradient: Gradient {
            GradientStop {
                position: 0
                color: "#566886"
            }
            GradientStop {
                position: 0.4
                color: "#405268"
            }
            GradientStop {
                position: 1
                color: "#172744"
            }
        } */
        Image {
            id: header_bg;
            source: "qrc:/res/header_meego.png"
            anchors.left: parent.left;
            anchors.right: parent.right;
            anchors.top: parent.top;
            anchors.bottom: parent.bottom;
            anchors.leftMargin: -1
            anchors.rightMargin: -1
            sourceSize.width: 480
            sourceSize.height: 80
            smooth: false
        }

        ToolIcon {
            id: toolbutton1
            anchors.left: parent.left
            anchors.verticalCenter: parent.verticalCenter
            iconId: "toolbar-list"
            onClicked: {
                pageStack.push(Qt.resolvedUrl("locationspage_meego.qml"))
                commonToolBar.tools = backLayout;
            }
        }

        ToolIcon {
            id: toolbutton2
            iconId: "toolbar-search"
            //text: qsTr("Refresh")
            //width: parent.width / 3
            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            onClicked: {
                //manualRefreshForecasts();
                pageStack.push(Qt.resolvedUrl("searchpage_meego.qml"))
                commonToolBar.tools = backLayout;
            }
        }

        Text {
            id: city
            font.pixelSize: 30
            text: ""
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
            anchors.right: toolbutton2.left
            anchors.left: toolbutton1.right
            anchors.verticalCenter: parent.verticalCenter
            color: "white"
            font.weight: Font.Bold
            elide: Text.ElideRight
            wrapMode: Text.NoWrap
        }

    }

    //Rectangle {
    Image {

        id: image_bg;
        source: "image://weather/bg_meego.png"
        anchors.left: parent.left;
        anchors.right: parent.right;
        anchors.top: header.bottom;
        //height: date_description.height + weather_big.height + weather_desc.height + banner.height + (15*Util.marginDefault)/4
        anchors.leftMargin: -1
        anchors.rightMargin: -1
        //width: sourceSize.width
        height: sourceSize.height
        sourceSize.width: 480
        sourceSize.height: 394
        smooth: true
        visible: (parent.width < parent.height)
    }

    Text {
        id: date_description
        text: ""
        color: "#859CBA"
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
        anchors.left: parent.left
        anchors.top: header.bottom
        anchors.topMargin: Util.marginDefault
        anchors.leftMargin: (parent.width - date_description.width - date_description_part2.width)/2
        wrapMode: Text.NoWrap
        elide: Text.ElideRight
        font.pixelSize: Util.minfontSize
    }

    Text {
        id: date_description_part2
        text: ""
        color: "#FFFFFF"
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
        anchors.left: date_description.right
        anchors.top: header.bottom
        anchors.topMargin: Util.marginDefault
        wrapMode: Text.NoWrap
        elide: Text.ElideRight
        font.pixelSize: Util.minfontSize
    }

    Image {
        id: weather_big
        smooth: true
        source: "qrc:/res/earth.png"
        anchors.top: date_description.bottom
        anchors.left: parent.left
        anchors.leftMargin: (5*width)/9
        //anchors.topMargin: Util.marginDefault / 2
        anchors.topMargin: 0 //Util.marginDefault / 4
        anchors.rightMargin: Util.marginDefault
        anchors.bottomMargin: Util.marginDefault / 2
        width: (7*Util.minSize) / 15
        height: (7*Util.minSize) / 15
        sourceSize.width: 240
        sourceSize.height: 240
    }

    Item {
        //color: "#000000"
        id: weatherColumn
        anchors.top: date_description.bottom
        anchors.right: parent.right
        anchors.bottom: weather_big.bottom
        anchors.left: weather_big.right
        anchors.leftMargin: (Util.marginDefault)/2
        anchors.rightMargin: Util.marginDefault
        anchors.verticalCenter: weather_big.verticalCenter
        Text {
            id: temperature
            anchors.left: parent.left
            anchors.top: parent.top
            anchors.topMargin: Util.marginDefault
            anchors.leftMargin: parent.width >> 4
            anchors.bottomMargin: parent.height >> 5
            //textFormat: Text.StyledText
            font.pixelSize: Util.mainTfontSize
            text:  ""
            color: "#FFFFFF"
        }
        Text {
            id: temperature_part2
            anchors.left: temperature.right
            anchors.top: parent.top
            anchors.topMargin: Util.marginDefault
            anchors.leftMargin: parent.width >> 6
            anchors.bottomMargin: parent.height >> 5
            //textFormat: Text.StyledText
            font.pixelSize: Util.mainTfontSize
            text:  ""
            color: "#859CBA"
        }
        Text {
            id: humidity
            anchors.left: parent.left
            anchors.top: temperature.bottom
            anchors.topMargin: (parent.height >> 5) + 1
            //anchors.bottom: temperature.bottom
            //anchors.bottomMargin: Util.minfontSize + (parent.height >> 4) + 1
            anchors.leftMargin: parent.width >> 4
            //textFormat: Text.StyledText
            font.pixelSize: Util.minfontSize
            text:  ""
            color: "#ffffff"
        }
        Text {
            id: humidity_part2
            anchors.left: humidity.right
            anchors.top: temperature.bottom
            anchors.topMargin: (parent.height >> 5) + 1
            //anchors.bottom: temperature.bottom
            //anchors.bottomMargin: Util.minfontSize + (parent.height >> 4) + 1
            anchors.leftMargin: parent.width >> 4
            //textFormat: Text.StyledText
            font.pixelSize: Util.minfontSize
            text:  ""
            color: "#859CBA"
        }
        Text {
            id: pressure
            anchors.left: parent.left
            anchors.top: humidity.bottom
            anchors.leftMargin: parent.width >> 4
            anchors.topMargin: (parent.height >> 5) + 1
            //textFormat: Text.StyledText
            font.pixelSize: Util.minfontSize
            text:  ""
            color: "#ffffff"
        }
        Text {
            id: pressure_part2
            anchors.left: pressure.right
            anchors.top: humidity.bottom
            anchors.leftMargin: parent.width >> 4
            anchors.topMargin: (parent.height >> 5) + 1
            //textFormat: Text.StyledText
            font.pixelSize: Util.minfontSize
            text:  ""
            color: "#859CBA"
        }
        Text {
            id: wind
            anchors.left: parent.left
            anchors.top: pressure.bottom
            anchors.leftMargin: parent.width >> 4
            anchors.topMargin: (parent.height >> 5) + 1
            //textFormat: Text.StyledText
            font.pixelSize: Util.minfontSize
            text:  ""
            color: "#ffffff"
        }
        Text {
            id: wind_part2
            anchors.left: wind.right
            anchors.top: pressure.bottom
            anchors.leftMargin: parent.width >> 4
            anchors.topMargin: (parent.height >> 5) + 1
            //textFormat: Text.StyledText
            font.pixelSize: Util.minfontSize
            text:  ""
            color: "#859CBA"
        }
        Image {
            id: windicon
            anchors.left: wind_part2.right
            anchors.leftMargin: Util.minfontSize/2
            anchors.verticalCenter: wind.verticalCenter
            source: "qrc:/res/wind.png"
            visible: false
            width: Util.minfontSize
            height: Util.minfontSize
            smooth: true
        }
    }

    Text {
        id: weather_desc
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: weather_big.bottom
        anchors.bottomMargin: Util.marginDefault/2
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.leftMargin: Util.marginDefault
        anchors.rightMargin: Util.marginDefault
        font.pixelSize: Util.minfontSize
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
        text:  ""
        color: "#859CBA"
        wrapMode: Text.WordWrap
    }

    Text {
        id: refreshed
        anchors.top: weather_desc.bottom
        anchors.topMargin: Util.marginDefault/2
        anchors.left: parent.left
        anchors.leftMargin: Util.marginDefault
        textFormat: Text.StyledText
        font.pixelSize: Util.minfontSize - 3
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
        text:  ""
        color: "#ffffff"
        wrapMode: Text.WordWrap
    }

    Image {
        id: banner
        smooth: true
        source: "qrc:/res/logo_meego.png"
        anchors.verticalCenter: refreshed.verticalCenter
        sourceSize.width: 122
        sourceSize.height: 36
        height: Util.minfontSize*3/2
        width: (height*sourceSize.width)/sourceSize.height
        anchors.right: parent.right
        anchors.rightMargin: Util.marginDefault
        MouseArea {
            anchors.fill: parent
            onClicked: {
                dlg.open();
            }
        }
    }

    Item {
        anchors.right: parent.right
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        anchors.topMargin: (parent.width > parent.height) ? 0 : (5*Util.marginDefault)/4
        anchors.top: (parent.width > parent.height) ? header.bottom : refreshed.bottom
        //color: "#000000"
        Rectangle {
            id: fcList_bg
            anchors.fill: parent
                gradient: Gradient {
                    GradientStop {
                        position: 0
                        color: "#374A68"
                    }
                    GradientStop {
                        position: 0.82
                        color: "#05080D"
                    }
                    GradientStop {
                        position: 1
                        color: "#05080D"
                    }
                }
/*            Image {
                id: fcList_fill;
                source: (root.width > root.height) ? "qrc:/res/bg_list_big_meego.png" : "qrc:/res/bg_list_meego.png"
                anchors.left: parent.left;
                anchors.right: parent.right;
                anchors.top: parent.top;
                anchors.bottom: parent.bottom;
                anchors.leftMargin: -1
                anchors.rightMargin: -1
                sourceSize.width: 480
                sourceSize.height: 248
                smooth: true
            } */
        }
        ListView {
            id: fcList
            visible: false
            anchors.fill: parent
            currentIndex: -1
            snapMode: ListView.SnapToItem
            orientation: ListView.Horizontal
            highlightFollowsCurrentItem: true
            model: ListModel {
                id: fcListModel
            }
            delegate: ForecastsListDelegate {id: fcListDelegate}
        }
        Image {
            id: left
            opacity: 0.7
            smooth: true
            visible: false
            source: "qrc:/res/left.png"
            anchors.left: fcList_bg.left
            anchors.top: fcList_bg.top
            anchors.topMargin: (fcList_bg.height - commonToolBar.height - height)/2 - ((mainPage.height < mainPage.width) ? (3*Util.marginDefault)/4 : 0)
            sourceSize.width: 14
            sourceSize.height: 18
            height: 18
            width: 14
        }
        Image {
            id: right
            opacity: 0.7
            smooth: true
            visible: false
            source: "qrc:/res/right.png"
            anchors.right: fcList_bg.right
            anchors.top: fcList_bg.top
            anchors.topMargin: (fcList_bg.height - commonToolBar.height - height)/2 - ((mainPage.height < mainPage.width) ? (3*Util.marginDefault)/4 : 0)
            sourceSize.width: 14
            sourceSize.height: 18
            height: 18
            width: 14
        }
    }

    Image {
        id: waitCursor
        smooth: true
        z: 1
        opacity: 0.66
        source: "qrc:/res/sand.png"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        sourceSize.width: 48
        sourceSize.height: 48
        height: sourceSize.height
        width: sourceSize.width
        visible: false
    }

/*
        states:
            State {
                name: "portrait"
            }
            State {
                name: "landscape"
            }
        state: (parent.width > parent.height) ? "landscape" : "portrait"

        transitions: [
            Transition {
                from: "landscape"
                to: "portrait"

            }
        ] */
}

