import QtQuick 1.0
import com.nokia.meego 1.0
import "util.js" as Util

PageStackWindow {
    initialPage: mainPage
    showStatusBar: true

    platformStyle: Style {
        property bool cornersVisible: false

        // Background
        //property string background: "image://theme/meegotouch-applicationpage-background"+__invertedString
        property string background: ""

        property string landscapeBackground: background
        property string portraitBackground: background
        property string portraiteBackground: background

        property int backgroundFillMode: Image.Tile
    }

    Page{
        property bool isStartPage: true
        //orientationLock: PageOrientation.LockPortrait

        id: mainPage
        anchors.top: parent.top //header.bottom
        anchors.bottom: commonToolBar.top
        Loader {
            anchors.fill: parent
            id: pageLoader
        }
        QueryDialog {
            id: dlg
            titleText: "Gismeteo"
            acceptButtonText: qsTr("Yes")
            rejectButtonText: qsTr("No")
            message: qsTr("open_gismeteo_in_browser")
            onAccepted: {
                var ext = factory.locale;
                if (factory.locale === "en")
                    ext = "com";
                var url = "http://www.gismeteo." + ext + "/city/weekly/" +
                    factory.locations[factory.currentLocation].id + '/';
                Qt.openUrlExternally(url);
            }
        }
        onStatusChanged: {
            if (status === PageStatus.Active) {
                buttonHourly.checked = !(factory.fDaily);
                buttonDaily.checked = factory.fDaily;
            }
        }
    }

    Component.onCompleted: {
        theme.inverted = true
        console.log("MeeGo layout");
        pageLoader.source = Qt.resolvedUrl("layout_meego.qml")
    }

    ToolBarLayout {
        id: mainLayout
        z: 1
        visible: true
            ToolIcon {
                iconId: "toolbar-back"
                visible: false
                onClicked: {
                    if (pageStack.depth > 1) pageStack.pop();
                    else {
                        factory.saveSettingsToDB();
                        Qt.quit();
                    };
                }
            }
/*            ToolIcon {
                iconId: "toolbar-refresh"
                onClicked: {
                    factory.emitRefresh();
                }
            } */
            Rectangle {
                id: leftRect
                width: (tb_rect.width > Util.minSize) ? 298 : 101//Utils.forecastMargin
                //width: (factory.landscape) ? 267 : 80
                opacity: 100
            }
            ButtonRow {
                anchors.bottom: parent.bottom
                anchors.bottomMargin: (mainPage.width > mainPage.height) ? 0 : 9
                Button {
                    id: buttonHourly
                    anchors.right: parent.width/2
                    anchors.rightMargin: -240
                    text: qsTr("Hourly")
                    onClicked: {
                        if (factory.fDaily) {
                            factory.fDaily = false;
                            factory.updateList();
                        }
                    }
                    style: ButtonStyle {
                        //backgroundMarginRight: 1
                        //background: "qrc:/res/meegotouch-button-background-horizontal-left.png"
                        checkedBackground: "qrc:/res/meegotouch-button-background-selected-horizontal-left.png"
                        background: "qrc:/res/meegotouch-button-background-horizontal-left.png"
                        //checkedBackground: "qrc:/res/meegotouch-button-background-selected-horizontal-left.png"
                        //pressedBackground: "image://theme/color10-meegotouch-button-background-pressed-horizontal-left"
                    }
                }
                Button {
                    id: buttonDaily
                    anchors.left: parent.left
                    anchors.leftMargin: parent.width/2 - 1
                    text: qsTr("Daily")
                    onClicked: {
                        if (!factory.fDaily) {
                            factory.fDaily = true;
                            factory.updateList();
                        }
                    }
                    platformStyle: ButtonStyle {
                        //backgroundMarginLeft: 1
                        //background: "qrc:/res/meegotouch-button-background-horizontal-right.png"
                        //checkedBackground: "qrc:/res/meegotouch-button-background-selected-horizontal-right.png"
                        background: "qrc:/res/meegotouch-button-background-horizontal-right.png"
                        checkedBackground: "qrc:/res/meegotouch-button-background-selected-horizontal-right.png"
                        //pressedBackground: "image://theme/color10-meegotouch-button-background-pressed-horizontal-right"
                    }
                }
            }
            Rectangle {
                id: rightRect
                width: (tb_rect.width > Util.minSize) ? 207 : 20 //Utils.forecastMargin
                //width: (factory.landscape) ? 227 : 40
                opacity: 100
            }
            ToolIcon {
                iconId: "toolbar-settings"
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("settingspage_meego.qml"))
                    commonToolBar.tools = settingsLayout;
                }
            }
        }

    ToolBarLayout {
        id: backLayout
        z: 1
        visible: false
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: {
                var Flag = factory.BackButtonEnabled;
                if (Flag) {
                    if (pageStack.depth == 2) {
                        //buttonHourly.text = (tb_rect.width > Util.minSize) ? "&!&!&" : "!!!";
                        commonToolBar.tools = mainLayout;
                    };
                    pageStack.pop();
                }
            }
        }
    }

    ToolBarLayout {
        id: settingsLayout
        z: 1
        visible: false
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: {
                if (pageStack.depth == 2) {
                    //buttonHourly.text = (tb_rect.width > Util.minSize) ? "&!&!&" : "!!!";
                    commonToolBar.tools = mainLayout;
                };
                pageStack.pop();
            }
        }
/*        ToolButton {
            text: qsTr("OK")
            onClicked: {
                factory.saveSettingsToDB();
            }
        } */
    }

    ToolBar {
        id: commonToolBar;
        anchors.bottom: parent.bottom
        tools: mainLayout

        Rectangle {
            id: down_line
            anchors.top: parent.top
            height: 1
            anchors.left: parent.left
            anchors.right: parent.right
            color: "#3A3A3A"
        }

        Rectangle {
            id: tb_rect
            anchors.fill: parent
            anchors.topMargin: 1
            opacity: 0.4
            gradient: Gradient {
                GradientStop {
                    position: 0
                    color: "#656565"
                }
                GradientStop {
                    position: 1
                    color: "#000000"
                }
            }
        }
    }

    Connections {
        target: factory

        onLanguageChangedSignal: {
            buttonHourly.text = qsTr("Hourly");
            buttonDaily.text = qsTr("Daily");
            dlg.message = qsTr("open_gismeteo_in_browser");
            dlg.acceptButtonText = qsTr("Yes");
            dlg.rejectButtonText = qsTr("No");
        }

    }
}
