import QtQuick 1.0
import Places 1.0
import "util.js" as Util
import com.nokia.meego 1.0
import com.nokia.extras 1.0

Page {
    id: searchpage
    //anchors.topMargin: st.height
    anchors.fill: parent

    property string prevInputText: ""
    property string prevFoundText: ""
    property int timeSinceKeyPressed: 0
    property int timeSinceMsgShown: 0
    property bool show2charsMsg: true
    property bool bFirst: true
    property int searchMode: 0

    function startSearch() {
        if (waitCursor.visible) {
            searchinfobanner.visible = false;
            return;
        };
        if (((searchstring.text !== "") || show2charsMsg) && (searchstring.text.length < 3)) {
            caption.text = qsTr("2_chars_entered");
            timeSinceMsgShown = 50;
            show2charsMsg = false;
            bFirst = false;
            searchinfobanner.visible = false;
            //searchinfobanner.timeout = 5000;
            //searchinfobanner.show();
        };
        if ((searchstring.text.length >= 3) && (!(searchMode == 1) || (searchstring.text !== prevFoundText))) {
            searchMode = 1;
            timeSinceKeyPressed = 0;
            searchList.showDistance = false;
            bFirst = false;
            searchList.model.clear();
            waitCursor.visible = true;
            searchinfobanner.visible = false;
            factory.findLocationsByName(searchstring.text);
        }
        prevFoundText = searchstring.text;
    }

    function startSearchByCoords() {
        if (!(waitCursor.visible)) {
            searchMode = 2;
            searchinfobanner.visible = false;
            factory.findMode = true;
            searchList.showDistance = true;
            searchList.model.clear();
            waitCursor.visible = true;
            searchinfobanner.visible = false;
            searchstring.text = "";
            prevFoundText = "";
            factory.getPosition();
        }
    }

    Rectangle {

        id: searchpageheader;
        z: 1
        anchors.left: parent.left;
        anchors.right: parent.right;
        anchors.top: parent.top;
        height: commonToolBar.height
/*        gradient: Gradient {
            GradientStop {
                position: 0
                color: "#566886"
            }
            GradientStop {
                position: 0.4
                color: "#405268"
            }
            GradientStop {
                position: 1
                color: "#172744"
            }
        } */
        Image {
            id: header_bg;
            source: "qrc:/res/header_meego.png"
            anchors.left: parent.left;
            anchors.right: parent.right;
            anchors.top: parent.top;
            anchors.bottom: parent.bottom;
            //anchors.topMargin: -1
            anchors.leftMargin: -1
            anchors.rightMargin: -1
            sourceSize.width: 480
            sourceSize.height: 80
            smooth: true
        }

        Text {
            id: caption
            font.pixelSize: 24
            text: qsTr("searchcaption")
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            anchors.margins: Util.forecastMargin
            color: "white"
            font.weight: Font.Light
            elide: Text.ElideRight
            wrapMode: Text.NoWrap
        }

    }

    Rectangle {
        id: textinputContainer
        height: (parent.width > parent.height) ? (commonToolBar.height*6)/5 : commonToolBar.height
        anchors.top: searchpageheader.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.topMargin: -1
        //anchors.bottomMargin: Util.marginDefault
        color: "#12223E"
        z: 1

        ToolIcon {
            id: toolbutton1srch
            z: 1
            anchors.left: parent.left
            iconSource: "qrc:/res/icon_search.png"
            onClicked: {
                bFirst = false;
                startSearchByCoords();
            }
        }

        ToolButton {
            id: toolbutton2srch
            z: 1
            text: qsTr("Find")
            width: Util.minSize/4
            anchors.right: parent.right
            anchors.rightMargin: Util.marginDefault/2
            anchors.verticalCenter: toolbutton1srch.verticalCenter
            onClicked: {
                searchinfobanner.visible = false;
                bFirst = false;
                show2charsMsg = true;
                startSearch();
            }
        }

        //Flickable {
        Rectangle {
            id: rectContainer
            z: 1
            height: (toolbutton1srch.height*7)/10
            //flickableDirection: Flickable.VerticalFlick
            anchors.top: parent.top
            anchors.left: toolbutton1srch.right
            anchors.right: toolbutton2srch.left
            anchors.rightMargin: Util.forecastMargin
            anchors.topMargin: toolbutton1srch.height/6
            color: "#12223E"
            TextField {
                id: searchstring
                width: rectContainer.width - 2*Util.forecastMargin
                anchors.fill: parent
                Keys.onReturnPressed: {
                    platformCloseSoftwareInputPanel();
                    dummy.focus = true;
                }
                //color: "#000000"
                //height: rectContainer.height
                //cursorVisible: true
                //focus: true
                font.pixelSize: Util.minfontSize
            }
        }
    }

    Rectangle {
        id: horzline
        height: 1
        anchors.top: textinputContainer.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        //anchors.topMargin: -1
        //anchors.bottomMargin: Util.marginDefault
        color: "#000000"
        z: 1
    }

    Rectangle {
        id: searchListContainer
        anchors.right: parent.right
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        anchors.top: textinputContainer.bottom
        //color: "#101620"
        gradient: Gradient {
            GradientStop {
                position: 0
                color: "#374A68"
            }
            GradientStop {
                position: 0.82
                color: "#05080D"
            }
            GradientStop {
                position: 1
                color: "#05080D"
            }
        }

        Text {
            id: searchinfobanner
            text: qsTr("2_chars_entered")
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.horizontalCenter: parent.horizontalCenter
            color: "white"
            font.pixelSize: 24 //Util.dailyTfontSize
            font.weight: Font.Light
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            anchors.margins: Util.forecastMargin
            width: parent.width - 2*Util.forecastMargin
            wrapMode: Text.WordWrap
            //elide: Text.ElideRight
            visible: true
        }


        ListView {
            id: searchList
            property bool showDistance: false
            anchors.fill: parent
            currentIndex: -1
            snapMode: ListView.SnapToItem
            orientation: ListView.Vertical
            highlightFollowsCurrentItem: true
            model: ListModel {
                id: locListModel
            }
            delegate: FoundLocListDelegate {id: flocListDelegate}
        }

    }

    Image {
        id: waitCursor
        smooth: true
        z: 1
        opacity: 0.66
        source: "qrc:/res/sand.png"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        sourceSize.width: 48
        sourceSize.height: 48
        height: sourceSize.height
        width: sourceSize.width
        visible: false
    }

    Item { id: dummy }

    Connections {
        target: factory
        onGotSearchResult: {
            var i=-1;
            var loc;
            if (factory.foundLocationsCount === 1) {
                searchstring.text = "";
                prevFoundText = "";
                caption.text = qsTr("no_places_found");
                timeSinceMsgShown = 50;
                //searchinfobanner.visible = true;
                searchList.model.clear();
                waitCursor.visible = false;
                //searchinfobanner.timeout = 5000;
                //searchinfobanner.show();
            } else {
                //caption.text = factory.foundLocationsCount;
                //timeSinceMsgShown = 50;
                for (i=0; i<factory.foundLocationsCount; i++) {
                    loc = factory.foundLocations[i];
                    searchList.model.append({"location": loc});
                    console.log(searchList.model.get(i).location.id);
                };
                searchstring.text = "";
                prevFoundText = "";
                searchList.currentIndex = -1; //0;
            };
            waitCursor.visible = false;
            searchList.visible = true;
        }
        onConnectionError: {
            waitCursor.visible = false;
            searchstring.text = "";
            prevFoundText = "";
            caption.text = qsTr("no_network");
            timeSinceMsgShown = 50;
        }
    }

    Timer {
        interval: 100; running: true; repeat: true;
        onTriggered: {
            if (searchstring.text === prevInputText) {
                timeSinceKeyPressed += 100;
            } else {
                prevInputText = searchstring.text;
                timeSinceKeyPressed = 0;
            };
            if (timeSinceKeyPressed >= 2000) {
                show2charsMsg = false;
                //timeSinceKeyPressed = 0;
                startSearch();
            }
            if (timeSinceMsgShown > 0) {
                timeSinceMsgShown += 100;
                if (timeSinceMsgShown > 2500) {
                    if (searchinfobanner.visible && !bFirst) {
                        searchinfobanner.visible = false;
                        //searchList.visible = true;
                    } else {
                        caption.text = qsTr("searchcaption");
                    }
                    timeSinceMsgShown = 0;
                }
            } else {
                if (searchinfobanner.visible && !bFirst) {
                    timeSinceMsgShown = 50;
                }
                caption.text = qsTr("searchcaption");
            }
        }
    }

    Component.onCompleted: {
    }

}
