var marginDefault = screen.displayHeight/30
// for S^3
//var minSize = (screen.displayHeight < screen.displayWidth) ? screen.displayHeight : screen.displayWidth
//var maxSize = (screen.displayHeight > screen.displayWidth) ? screen.displayHeight : screen.displayWidth
// for MeeGo
var minSize = 480
var maxSize = 854
var minfontSize = minSize/20
var hintfontSize = minSize/24
var mainTfontSize = minSize/8
var dailyTfontSize = minSize/12
var locationFontSize = minSize/15
var refreshedTimeInMs = undefined
var descriptionRowHeight = 0
var fcDescriptionRowHeight = 0
var minForecastWidth = minSize/4
var maxForecastWidth = maxSize/6
var minLocationHeight = minSize/4
var temperatureWidth = (2*minSize)/11
var forecastMargin = minForecastWidth/10
var forecastDescrMargin = forecastMargin
var currentForecastIndx = 0
var forecastFontSize = minfontSize - 5

function millimetersToPixels(number) {
    return Math.round(number * screen.dpi / 25.4);
}

function __db()
{
    return openDatabaseSync("gismeteo", "1.0", "", 100000);
}

function __ensureTables(tx)
{
    tx.executeSql('CREATE TABLE IF NOT EXISTS userdata(imei TEXT, userhash TEXT)');
    tx.executeSql('CREATE TABLE IF NOT EXISTS settings(lastreadtime REAL, lastplace INT)');
    //tx.executeSql('CREATE TABLE IF NOT EXISTS locations(placeid INT, name TEXT)');
    var strQuery = "CREATE TABLE IF NOT EXISTS forecasts(validtime REAL, placeid INT, forecastType INT, dayTime INT, description TEXT, icons TEXT, " +
        "temperatureCMin INT, temperatureCMax INT, windSpeedMetersPerSecondMin INT, windSpeedMetersPerSecondMax INT, " +
        "pressureMmHgMin INT, pressureMmHgMax INT, humidityMin INT, humidityMax INT, " +
        "thunderProbability INT, waterTemperatureC INT, feelsTemperatureC INT, " +
        "sunRiseMin INT, sunSetMin INT, sunDurationM INT, geoMagneticGrade INT, weatherEvent INT, " +
        "windDirection INT, precipitationLevel INT, precipitationType INT, cloudinessLevel INT)";
    tx.executeSql(strQuery);
}

function getHashFromDb(imei) {
    var hash = undefined;
    __db().transaction(
                function(tx) {
                    // Create the database if it doesn't already exist
                    __ensureTables(tx);

                    var rs = tx.executeSql('SELECT userhash FROM userdata WHERE imei=?',[imei]);

                    if (rs.rows.length > 0) {
                        hash = rs.rows.item(0).userhash;
                    }
                }
                )
    return hash;
}

function insertHash(imei,hash) {
    __db().transaction(
                function(tx) {
                    // Create the database if it doesn't already exist
                    __ensureTables(tx);

                    tx.executeSql('INSERT INTO userdata VALUES (?, ?)',[imei,hash]);

                }
                )
}

function parseError(docElement) {
    return {"code":(+docElement.childNodes[1].childNodes[0].nodeValue),
        "message":docElement.childNodes[3].childNodes[0].nodeValue};
}

function updateForecastsForLoc(cityid) {
    __db().transaction(
                function(tx) {
                    __ensureTables(tx);
                    tx.executeSql('DELETE FROM forecasts WHERE placeid=?',[cityid]);

                    var locIndex;
                    var fFound = false;
                    for (locIndex = 0; locIndex < factory.locationsCount; locIndex++) {
                        if (factory.locations[locIndex].id == cityid) {
                            fFound = true; break;
                        }
                    };
                    if (fFound) {
                        for (var fcIndex = 0; fcIndex < factory.locations[locIndex].forecastsCount; fcIndex++) {
                            var dateString = factory.locations[locIndex].forecasts[fcIndex].dateTime;
                            var dateValue = (((parseInt(dateString.substring(0,4),10)*100+parseInt(dateString.substring(5,7),10))*100 +
                                parseInt(dateString.substring(8,10),10)) * 2000 +
                                (parseInt(dateString.substring(11,13),10)*60 + parseInt(dateString.substring(14,16),10)))/2000;
                            console.log(dateValue);
                        };
                        return 1;
                    }
                    else return 0;
                }
                )
}

function updateLocationsFromDB(factory) {
    __db().transaction(
                function(tx) {
                    __ensureTables(tx);
                    console.log("!!!!!!!!!!!!!!!");
                    var rs = tx.executeSql('SELECT * FROM locations WHERE 1=1');
                    console.log(rs.rows.length);
                    for(var i = 0; i < rs.rows.length; i++) {
                        console.log("city name: ");
                        console.log(rs.rows.item(i).name);
                        console.log(rs.rows.item(i).district);
                        factory.addLocation(rs.rows.item(i).placeid, rs.rows.item(i).name, rs.rows.item(i).district, rs.rows.item(i).country);
                    }
                }
                )
}

function humidityText() {
    return qsTr("humidity")
}

function humidityText100() {
    return qsTr("hum")
}

function mpsText() {
    return qsTr("mps")
}

function kmhText() {
    return qsTr("kmh")
}

function mmhgText() {
    return qsTr("mmHg")
}

function gpaText() {
    return qsTr("gPa")
}

function msg5places() {
    return qsTr("message_5_places")
}

const WindDir = [qsTr('Calm'), qsTr('N'), qsTr('NE'), qsTr('E'), qsTr('SE'), qsTr('S'), qsTr('SW'), qsTr('W'), qsTr('NW')];
//const DayOfWeek = [qsTr('Sunday'),qsTr('Monday'),qsTr('Tuesday'),qsTr('Wednesday'),qsTr('Thursday'),qsTr('Friday'),qsTr('Saturday')];

function getWindDirection(dir) {
    return WindDir[dir];
}

//function getDayOfWeek(count) {
//    return DayOfWeek[count];
//}
